/**
 * Map a single item or an array of items
 *
 * @export
 * @template T
 * @template U
 * @param {(T|Array<T>)} data Data to iterate over
 * @param {(item: T) => U} fn Function called for every data item
 * @returns {(U|Array<U>|null)} Return value of the callback function
 */
export declare function mapItems<T, U>(data: Array<T>, fn: (item: T) => U): Array<U>;
export declare function mapItems<T, U>(data: T, fn: (item: T) => U): U | null;
/**
 * Flatten a 2D array to a single array
 *
 * @export
 * @template T
 * @param {Array<Array<T>|T>} data Arrays to flatten
 * @returns {Array<T>} Flattened array
 */
export declare function flatten<T>(data: Array<Array<T> | T>): Array<T>;
/**
 * Check if the given variable is an array with at least one falsy value
 *
 * @export
 * @param {any} value A variable to check
 * @returns {boolean} The given variable is an array with at least one falsy value
 */
export declare function isFalsyArray(value: any): boolean;
/**
 * Add a computed property to an observable object
 *
 * @export
 * @param {object} obj Observable object
 * @param {string} key Property to add
 * @param {() => any} getter Getter function
 * @param {(value: any) => void} [setter] Setter function
 */
export declare function assignComputed<T = any>(obj: object, key: string, getter?: () => T, setter?: (value: T) => void): void;
export declare function error(...args: Array<any>): void;
export declare function warn(...args: Array<any>): void;
export declare function deprecated(...args: Array<any>): void;
export declare function info(...args: Array<any>): void;
